﻿using Hotline.Share.Enums.FlowEngine;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Share.Dtos.FlowEngine.Definition
{
    /// <summary>
    /// 模板定义节点
    /// </summary>
    public class StepDefineBasic
    {
        public string Name { get; set; }

        /// <summary>
        /// 模板内唯一
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 办理/汇总、开始/结束
        /// </summary>
        public EStepType StepType { get; init; }

        /// <summary>
        /// 业务属性
        /// </summary>
        public EBusinessProperty BusinessProperty { get; set; }

        /// <summary>
        /// 办理者类型
        /// </summary>
        public EHandlerType HandlerType { get; set; }

        /// <summary>
        /// 办理者类型下的配置（或是直接保存办理者）
        /// <example>
        /// 根据类型可能为：roles, orgLevels, orgTypes, orgCodes, userIds
        /// </example>
        /// </summary>
        public List<KeyValuePair<string, string>> HandlerTypeItems { get; set; } = new();

        /// <summary>
        /// 是否支持发起会签
        /// </summary>
        public bool CanStartCountersign { get; set; }

        /// <summary>
        /// 会签策略
        /// </summary>
        public ECountersignPolicy? CountersignPolicy { get; set; }

        /// <summary>
        /// 是否有否决按钮
        /// </summary>
        public bool CanReject { get; set; }

        /// <summary>
        /// 执行模式(自动与否)
        /// </summary>
        public EExecuteMode ExecuteMode { get; set; }

        /// <summary>
        /// 实例化模式
        /// </summary>
        public EInstanceMode InstanceMode { get; set; }

        /// <summary>
        /// 循环策略(loop才有)
        /// </summary>
        public ELoopPolicy? LoopPolicy { get; set; }

        /// <summary>
        /// 到此标记loop终止(loop才有)
        /// <remarks>
        /// 按直属部门循环既保存orgId
        /// </remarks>
        /// </summary>
        public string? TerminalLoopTag { get; set; }

        /// <summary>
        /// 标签
        /// </summary>
        public string? Tag { get; set; }

        /// <summary>
        /// 可跳转节点
        /// </summary>
        public List<StepDefineSimple> NextSteps { get; set; }
    }
}
